import { ApiProperty } from '@nestjs/swagger';
import { Allowance } from '~/allowance/entities';
import { AllowanceFrequency, AllowanceType } from '~/allowance/enums';
import { JuniorResponseDto } from '~/junior/dtos/response';

export class AllowanceResponseDto {
  @ApiProperty({ example: 'd641bb71-2e7c-4e62-96fa-2785f0a651c6' })
  id!: string;

  @ApiProperty({ example: 'Allowance name' })
  name!: string;

  @ApiProperty({ example: 100 })
  amount!: number;

  @ApiProperty({ example: AllowanceFrequency.WEEKLY })
  frequency!: AllowanceFrequency;

  @ApiProperty({ example: AllowanceType.BY_END_DATE })
  type!: AllowanceType;

  @ApiProperty({ example: new Date() })
  startDate!: Date;

  @ApiProperty({ example: new Date() })
  endDate?: Date;

  @ApiProperty({ example: 10 })
  numberOfTransactions?: number;

  @ApiProperty({ type: JuniorResponseDto })
  junior!: JuniorResponseDto;

  @ApiProperty({ example: new Date() })
  createdAt!: Date;

  @ApiProperty({ example: new Date() })
  updatedAt!: Date;

  constructor(allowance: Allowance) {
    this.id = allowance.id;
    this.name = allowance.name;
    this.amount = allowance.amount;
    this.frequency = allowance.frequency;
    this.type = allowance.type;
    this.startDate = allowance.startDate;
    this.endDate = allowance.endDate;
    this.numberOfTransactions = allowance.numberOfTransactions;
    this.junior = new JuniorResponseDto(allowance.junior);
    this.createdAt = allowance.createdAt;
    this.updatedAt = allowance.updatedAt;
  }
}
