import { Injectable, Logger } from '@nestjs/common';
import { DocumentType } from '~/document/enums';
import { DocumentService, OciService } from '~/document/services';

@Injectable()
export class LookupService {
  private readonly logger = new Logger(LookupService.name);
  constructor(private readonly documentService: DocumentService, private readonly ociService: OciService) {}
  async findDefaultAvatar() {
    this.logger.log(`Finding default avatar`);
    const documents = await this.documentService.findDocuments({ documentType: DocumentType.DEFAULT_AVATAR });
    await Promise.all(
      documents.map(async (document) => {
        document.url = await this.ociService.generatePreSignedUrl(document);
      }),
    );

    this.logger.log(`Default avatar returned successfully`);

    return documents;
  }

  async findDefaultTasksLogo() {
    this.logger.log(`Finding default tasks logos`);
    const documents = await this.documentService.findDocuments({ documentType: DocumentType.DEFAULT_TASKS_LOGO });

    await Promise.all(
      documents.map(async (document) => {
        document.url = await this.ociService.generatePreSignedUrl(document);
      }),
    );

    this.logger.log(`Default tasks logos returned successfully`);
    return documents;
  }
}
