import { Column, Entity, OneToMany, OneToOne, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm';
import { Customer } from '~/customer/entities';
import { Gift } from '~/gift/entities';
import { Junior, Theme } from '~/junior/entities';
import { SavingGoal } from '~/saving-goals/entities';
import { Task } from '~/task/entities';
import { TaskSubmission } from '~/task/entities/task-submissions.entity';
import { User } from '~/user/entities';
import { DocumentType } from '../enums';

@Entity('documents')
export class Document {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column({ type: 'varchar', length: 255 })
  name!: string;

  @Column({ type: 'varchar', length: 255 })
  extension!: string;

  @Column({ type: 'varchar', length: 255, name: 'document_type' })
  documentType!: DocumentType;

  @OneToOne(() => Customer, (customer) => customer.profilePicture, { onDelete: 'SET NULL' })
  customerPicture?: Customer;

  @OneToOne(() => Junior, (junior) => junior.civilIdFront, { onDelete: 'SET NULL' })
  juniorCivilIdFront?: User;

  @OneToOne(() => Junior, (junior) => junior.civilIdBack, { onDelete: 'SET NULL' })
  juniorCivilIdBack?: User;

  @OneToMany(() => Theme, (theme) => theme.avatar)
  themes?: Theme[];

  @OneToMany(() => Task, (task) => task.image)
  tasks?: Task[];

  @OneToMany(() => TaskSubmission, (taskSubmission) => taskSubmission.proofOfCompletion)
  submissions?: TaskSubmission[];

  @OneToMany(() => SavingGoal, (savingGoal) => savingGoal.image)
  goals?: SavingGoal[];

  @OneToMany(() => Gift, (gift) => gift.image)
  gifts?: Gift[];

  @UpdateDateColumn({ name: 'updated_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;

  @Column({ name: 'created_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  // virtual field
  url?: string;
}
