import { ApiProperty } from '@nestjs/swagger';
import { DocumentMetaResponseDto } from '~/document/dtos/response';
import { Gift } from '~/gift/entities';
import { GiftColor, GiftStatus } from '~/gift/enums';
import { JuniorResponseDto } from '~/junior/dtos/response';

export class GiftDetailsResponseDto {
  @ApiProperty({ example: 'f7b9b1b0-0b3b-4b3b-8b3b-0b3b4b3b8b3b' })
  id!: string;

  @ApiProperty({ example: 'Happy Birthday' })
  name!: string;

  @ApiProperty({ example: 'Description of the gift' })
  description!: string;

  @ApiProperty({ example: '200' })
  amount!: number;

  @ApiProperty({ example: GiftStatus.AVAILABLE })
  status!: GiftStatus;

  @ApiProperty({ example: GiftColor.GREEN })
  color!: GiftColor;

  @ApiProperty({ type: JuniorResponseDto })
  recipient!: JuniorResponseDto;

  @ApiProperty({ example: 'Ahmad Khalid' })
  giverName!: string;

  @ApiProperty({ type: DocumentMetaResponseDto })
  image!: DocumentMetaResponseDto;

  @ApiProperty({ example: '2022-01-01T00:00:00.000Z' })
  createdAt!: Date;

  @ApiProperty({ example: '2022-01-01T00:00:00.000Z' })
  updatedAt!: Date;

  constructor(gift: Gift) {
    this.id = gift.id;
    this.name = gift.name;
    this.description = gift.description;
    this.amount = gift.amount;
    this.status = gift.status;
    this.color = gift.color;
    this.giverName = gift.giver.customer.firstName + ' ' + gift.giver.customer.lastName;
    this.recipient = new JuniorResponseDto(gift.recipient);
    this.image = new DocumentMetaResponseDto(gift.image);
    this.createdAt = gift.createdAt;
    this.updatedAt = gift.updatedAt;
  }
}
