import { HttpService } from '@nestjs/axios';
import { Injectable, Logger } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class BranchIoService {
  private readonly logger = new Logger(BranchIoService.name);
  private readonly branchIoKey = this.configService.getOrThrow<string>('BRANCH_IO_KEY');
  private readonly branchIoUrl = this.configService.getOrThrow<string>('BRANCH_IO_URL');
  constructor(private readonly configService: ConfigService, private readonly httpService: HttpService) {}

  async createBranchLink(token: string) {
    this.logger.log(`Creating branch link`);
    const payload = {
      branch_key: this.branchIoKey,
      channel: 'junior',
      feature: 'invite',
      alias: token,
    };

    const response = await this.httpService.axiosRef({
      url: this.branchIoUrl,
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: payload,
    });
    return response.data.url;
  }
}
