import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  JoinTable,
  ManyToMany,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { Document } from '~/document/entities';
import { Junior } from '~/junior/entities';
import { Category } from './category.entity';
const ZERO = 0;
@Entity('saving_goals')
export class SavingGoal extends BaseEntity {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column({ type: 'varchar', length: 255, name: 'name' })
  name!: string;

  @Column({ type: 'varchar', length: 255, name: 'description', nullable: true })
  description!: string;

  @Column({ type: 'timestamp with time zone', name: 'due_date' })
  dueDate!: Date;

  @Column({
    type: 'decimal',
    name: 'target_amount',
    precision: 12,
    scale: 3,
    transformer: { to: (value: number) => value, from: (value: string) => parseFloat(value) },
  })
  targetAmount!: number;

  @Column({
    type: 'decimal',
    name: 'current_amount',
    precision: 12,
    scale: 3,
    default: ZERO,
    transformer: { to: (value: number) => value, from: (value: string) => parseFloat(value) },
  })
  currentAmount!: number;

  @Column({ type: 'uuid', name: 'image_id', nullable: true })
  imageId!: string;

  @Column({ type: 'uuid', name: 'junior_id' })
  juniorId!: string;

  @ManyToOne(() => Document, (document) => document.goals, { onDelete: 'CASCADE', nullable: true })
  @JoinColumn({ name: 'image_id' })
  image!: Document;

  @ManyToOne(() => Junior, (junior) => junior.goals, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'junior_id' })
  junior!: Junior;

  @ManyToMany(() => Category, (category) => category.goals)
  @JoinTable({
    name: 'saving_goals_categories',
    joinColumn: { name: 'saving_goal_id', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'category_id', referencedColumnName: 'id' },
  })
  categories!: Category[];

  @CreateDateColumn({ type: 'timestamp', name: 'created_at', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  @CreateDateColumn({ type: 'timestamp', name: 'updated_at', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;
}
