import { ApiProperty } from '@nestjs/swagger';
import { DocumentMetaResponseDto } from '~/document/dtos/response';
import { JuniorResponseDto } from '~/junior/dtos/response';
import { Task } from '~/task/entities';
import { TaskSubmissionDetailsResponsetDto } from './task-submission-details.response.dto';

export class TaskResponseDto {
  @ApiProperty()
  id!: string;

  @ApiProperty()
  title!: string;

  @ApiProperty()
  description!: string;

  @ApiProperty()
  status!: string;

  @ApiProperty()
  dueDate!: Date;

  @ApiProperty()
  rewardAmount!: number;

  @ApiProperty()
  isProofRequired!: boolean;

  @ApiProperty()
  submission?: TaskSubmissionDetailsResponsetDto | null;

  @ApiProperty()
  junior!: JuniorResponseDto;

  @ApiProperty()
  image!: DocumentMetaResponseDto;

  @ApiProperty()
  createdAt!: Date;

  @ApiProperty()
  updatedAt!: Date;

  constructor(task: Task) {
    this.id = task.id;
    this.title = task.title;
    this.description = task.description;
    this.status = task.status;
    this.dueDate = task.dueDate;
    this.rewardAmount = task.rewardAmount;
    this.isProofRequired = task.isProofRequired;
    this.submission = task.submission ? new TaskSubmissionDetailsResponsetDto(task.submission) : null;
    this.image = new DocumentMetaResponseDto(task.image);
    this.junior = new JuniorResponseDto(task.assignedTo);
    this.createdAt = task.createdAt;
    this.updatedAt = task.updatedAt;
  }
}
